====================================
Django Yarr - Yet Another RSS Reader
====================================

A lightweight customisable RSS reader for Django.

* Project site: https://radiac.net/projects/django-yarr/
* Source code: https://github.com/radiac/django-yarr

.. image:: https://github.com/radiac/django-yarr/actions/workflows/ci.yml/badge.svg
    :target: https://github.com/radiac/django-yarr/actions/workflows/ci.yml

.. image:: https://codecov.io/gh/radiac/django-yarr/branch/develop/graph/badge.svg?token=5VZNPABZ7E
    :target: https://codecov.io/gh/radiac/django-yarr


Features
========

* Easy to install - simple requirements, just drops into your site
* Import and export list of feeds using OPML
* View all, by feed, just unread or saved items
* List or expanded layout
* Mark items as read or saved
* Infinite scrolling, with keyboard support and automatic mark as read
* Support for multiple users
* Manage subscriptions through user views or admin site
* No social nonsense

Supports Django 2.2 and later, on Python 3.5 and later.

See `Installation <docs/installation.rst>`_ for installation instructions.

See `Upgrading <docs/upgrading.rst>`_ for changelog and upgrade instructions
